# Edinburgh LaTeX

LaTeX styles files for School of Math, University of Edinburgh. This includes:

- [edmaths.sty](#Report-Stylesheet), report and thesis stylesheet,
- [beamerthemeedmaths.sty](#Beamer-Theme), presentation theme,
- [beamernotes.sty](#Beamer-Notes), for [pdfpc](https://pdfpc.github.io/) compatible presentation notes.

To use, download the files and store them either with your `.tex` file(s) or in any directory that's findable by LaTeX (e.g. `$TEXINPUTS`).

## Report Stylesheet

When working on a report or thesis, an easy way to implement the University’s typesetting rules in LaTeX is provided by [edmaths.sty](https://github.com/Foggalong/edinburgh-math-latex/blob/master/edmaths.sty). It sets the page margins as required and defines commands to create the correct cover page and standard declaration.

It also loads the [amsmath](https://www.ctan.org/pkg/amsmath), [amsthm](https://www.ctan.org/pkg/amsthm), [amscd](https://www.ctan.org/pkg/amscd), and [amssymb](https://ctan.org/pkg/amsfonts) packages, which are required by almost all mathematical publications. Through [setspace](https://www.ctan.org/pkg/setspace), line spacing settings are available that only affect the body text and not footnotes and captions.

### Requirements

The basic package has no special requirements, but if you have certain additional packages installed then you can use some fancifying options (see below).

### Setup

1. Use the report document class (via `\documentclass[…]{report}`) with options
    1. for font size: `10pt`, `11pt`, `12pt`;
    2. for sidedness: `oneside` (default), `twoside`.
2. Define `\title{…}`, `\author{…}`, and `\date{…}`.
3. Add the line `\usepackage[<options>]{edmaths}` to your preamble.

The steps must be in order or you will get errors.

Here `<options>` is a comma-separated list of the following keywords:

| Keyword | Effect |
| :------ | :----- |  
| One of `firstyear`, `secondyear`, `thirdyear`, `fourthyear`, `phd`, `masterph`, or `mastersc` for postgrad projects, or `mmath` or `y4project` for undergraduate projects. | Prints the correct degree name or report type on the cover page. If you do not specify any of these, set `\degreetext` manually before including this package, e.g. `\newcommand{\degreetext}{Internal Report}` |
| `single`, `onehalf`, or `double` | Set line spacing of the body text to single, one-half and double spaced, respectively. Check out [setspace](https://www.ctan.org/pkg/setspace) for custom spacing options. |
| `fourier` | This provides much improved typography by activating the fourier font package (based on [Adobe’s Utopia](https://fonts.adobe.com/fonts/utopia) family) along with the [cmap](https://www.ctan.org/pkg/cmap) and [microtype](https://www.ctan.org/pkg/microtype) packages; all those are required for this option. |
| `hyperref` | If the [hyperref](https://www.ctan.org/pkg/hyperref) and [xcolor](https://www.ctan.org/pkg/xcolor) packages are installed, this creates PDF output with clickable and all-black links. The packages are set up with sane default options, but to modify the behaviour, simply use the `\hypersetup` command; see the `hyperref` documentation for details. |
| `colour` | If the `hyperref` option is used, this sets clickable links to have a sane default colour (sepia for internal links, blue for external URLs). |
| `fancyhdr` | If the [fancyhdr](https://www.ctan.org/pkg/fancyhdr) package is installed, this creates nice page headers and footers (with sane default settings); to modify this behaviour, simply use the commands described in the `fancyhdr` documentation. This may produce warnings if used without `twoside` in the `documentclass`.

### Usage

Once `edmaths` is set up, use `\maketitle` to create the cover page, `\declaration` to create the standard declaration, `\dedication{…}` for a dedication page, the `\begin{abstract}…\end{abstract}` environment for the abstract, and `\tableofcontents` for the table of contents. To redefine the title of the abstract, use `\renewcommand{\abstractname}{My New Title}`.

When using the `y4project` option, the command `\yfourdeclaration{…}` can be used right after the abstract to print a declaration at the bottom of that page; the argument of this command is the name of the particular degree.

## Beamer Theme  

The file [beamerthemedmaths.sty](https://github.com/Foggalong/edinburgh-math-latex/blob/master/beamerthemeedmaths.sty) gives a modification of the [Usher Institute](https://www.ed.ac.uk/usher)'s theme for LaTeX/beamer presentations which uses the standard university branding.

### Colourful Variants

The default theme `\usetheme{edmaths}` gives is 'UoE Blue', `#00325F`, but there are other colourscheme variations:

- `\usetheme[colour=UoEcyan]{edmaths}` for `#CC5911`,
- `\usetheme[colour=UoEgreen]{edmaths}` for `#9C9A00`,
- `\usetheme[colour=UoEorange]{edmaths}` for `#457E81`.

## Examples

These files are bundled with an example report and presentation, as well as a bibliography file for use across both. There are also simple examples of a [report](https://github.com/Foggalong/edinburgh-math-latex/wiki/Example-Report) and [presentation](https://github.com/Foggalong/edinburgh-math-latex/wiki/Example-Presentation) in the project wiki, as well as some [further formatting suggestions](https://github.com/Foggalong/edinburgh-math-latex/wiki/Further-Suggestions).

## Beamer Notes

If you use [pdf-presenter-console](https://pdfpc.github.io/), a
presenter console with multi-monitor support for PDF files, you can use

```latex
\usepackage{beamernotes}
```

and enter slide notes as in

```latex
\bnote{my notes}
```

_after_ the `frame` you want to annotate. The contents will generate a `filename.pdfpc` file containing
all notes to be shown by pdfpc. Note that **this does not support newlines**.

## Authors

While [Josh Fogg](https://github.com/Foggalong) maintains these versions, they would not have been possible without the work of:

- [Thomas Köppe](https://github.com/tkoeppe), wrote the original `edmaths` style file;
- [Saturnino Luz](https://www.ed.ac.uk/profile/saturnino-luz), created the original `beamernotes` and Beamer template for the [Usher Institute](https://www.ed.ac.uk/usher);
- [Ben Brown](https://github.com/bencwbrown), modified the Beamer theme for general UoE usage.

Issues can be flagged [on GitHub](https://github.com/Foggalong/edinburgh-math-latex/issues) by [by email](mailto:j.fogg@ed.ac.uk). The license for the Beamer files is LPPL 3c. The licenses for all other files are [unknown](https://github.com/Foggalong/edinburgh-math-latex/issues/1).
